@@ -21,6 +21,15 @@ class StrHelper:
     def __element_count(arr, target):
         return arr.count(target)
 
+    @staticmethod
+    def is_string(obj):
+        try:
+            obj.lower() + obj.title() + obj + ""
+        except Exception, ex:
+            return False
+        else:
+            return True
+
     @staticmethod
     def __reg_find_data(reg_pattern, search_data):
         data_search = []
